References
----------

**Workshops**

* Heinen, J. (2014), "Scientific Visualization". Workshop, PGI/JCNS, Forschungszentrum Jülich (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/sci-vis.pdf>`__, `HTML <http://iffwww.iff.kfa-juelich.de/pub/doc/sci-vis/>`__)

**Poster Sessions**

* Heinen, J. (2013), `"GR - a universal framework for visualization applications" <https://us.pycon.org/2013/schedule/presentation/158>`__. `PyCon US 2013 <https://us.pycon.org/2013>`__, Santa Clara, CA (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/GR-A_Universal_Framework_for_Visualization_Applications.pdf>`__, `Poster <http://iffwww.iff.kfa-juelich.de/pub/doc/PyCon_US_2013_GR-A_Universal_Framework_for_Visualization_Applications.pdf>`__, `Video <https://www.youtube.com/watch?v=LqX_ZHwWRW8>`__)

**Talks**

* Heinen, J. (2014), `"Scientific Visualization with GR" <https://ep2014.europython.eu/en/schedule/sessions/86/>`__. `EuroPython 2014 <https://ep2014.europython.eu>`__, Berlin (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/Scientific_Visualization_with_GR.pdf>`__, `Video <http://www.youtube.com/watch?v=-oSAMkqbWjs>`__, `HTML <http://iffwww.iff.kfa-juelich.de/pub/doc/EP14>`__)

* Heinen, J. (2013), `"Was Sie schon immer über „Visualisierung mit Python“ wissen wollten" <https://2013.de.pycon.org/schedule/sessions/45>`__. `PyCon.DE 2013 <https://2013.de.pycon.org>`__, Köln (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/Was_Sie_schon_immer_ueber_Visualisierung_mit_Python_wissen_wollten.pdf>`__, `Video <https://www.youtube.com/watch?v=muvvgXc8Xlw>`__, `HTML <http://iffwww.iff.kfa-juelich.de/pub/doc/PyCon_DE_2013>`__)

* Heinen, J. (2013), "GR Framework / MODBUS on Raspberry Pi". PythonCamp 2013, Cologne (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/GR_Framework_&_MODBUS_on_Raspberry_Pi.pdf>`__)

* Heinen, J. (2012), `"GR - ein universelles Framework für Visualisierungsanwendungen" <https://2012.de.pycon.org/programm/schedule/sessions/54>`__. `PyCon DE 2012 <https://2012.de.pycon.org>`__, Leipzig (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/GR-ein_universelles_Framework_fuer_Visualisierungsanwendungen.pdf>`__, `Video <http://www.youtube.com/watch?v=EhLPAEUI4l0>`__)

* Rhiem, F. (2012), "Integration von 3D-Visualisierungstechniken in 2D-Grafiksystemen". Kolloquium, FH Aachen, Campus Jülich (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/Bachelorvortrag_FlorianRhiem.pdf>`__)

* Heimbach, I. (2012), "Definition und Implementierung eines Metamodells zur Vereinheitlichung der Visualisierung in grafischen Bedienoberflächen". Kolloquium, FH Aachen, Campus Jülich (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/Bachelorvortrag_IngoHeimbach.pdf>`__)

* Heinen, J. (2012), "GR - A universal framework for visualization applications". Jülich Centre for Neutron Science (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/GR%20-%20A%20universal%20framework%20for%20visualization%20applications.pdf>`__)

* Heinen, J. (2011), "Neutron Science Visualization Software". Jülich Centre for Neutron Science (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/Neutron%20Science%20Visualization%20Software.pdf>`__)

**Thesis**

* Knodt, D. (2013), "Programmierung eines GKS-Plugins in Python zur Erzeugung von statischen JavaScript/HTML5 Inhalten". Seminararbeit, FH Aachen, Campus Jülich (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/Bachelorarbeit_DavidKnodt.pdf>`__)

* Winkler, J. (2013), "Entwicklung eines logischen GKS Gerätetreibers auf der Basis von OpenGL". Bachelorarbeit, FH Aachen, Campus Jülich (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/Bachelorarbeit_JoergWinkler.pdf>`__)

* Knodt, D. (2012), "Erstellen von MPEG-4 Videos aus PDF-Seiten auf Basis der Bibliotheken MuPDF und Libav". Seminararbeit, FH Aachen, Campus Jülich (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/Seminararbeit_DavidKnodt.pdf>`__)

* Winkler, J. (2012), "Rasterisierung von Vektor-Schriften auf der Basis der FreeType Software". Seminararbeit, FH Aachen, Campus Jülich (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/Seminararbeit_JoergWinkler.pdf>`__)

* Dück, M. (2012), "Integration von mobilen iOS Geräten der Firma Apple in Instrumentierungsanwendungen". Masterarbeit, FH Aachen, Campus Jülich (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/Masterarbeit_MarcelDueck.pdf>`__)

* Rhiem, F. (2012), "Integration von 3D-Visualisierungstechniken in 2D-Grafiksystemen". Bachelorarbeit, FH Aachen, Campus Jülich (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/Bachelorarbeit_FlorianRhiem.pdf>`__)

* Heimbach, I. (2012), "Definition und Implementierung eines Metamodells zur Vereinheitlichung der Visualisierung in grafischen Bedienoberflächen". Bachelorarbeit, FH Aachen, Campus Jülich (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/Bachelorarbeit_IngoHeimbach.pdf>`__)

* Felder, C. (2011), "Implementierung einer Visualisierungsanwendung für Apples iOS". Masterarbeit, FH Aachen, Campus Jülich (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/Masterarbeit_ChristianFelder.pdf>`__)

* Rhiem, F. (2011), "Integration OpenGL-basierter Visualisierungs-Techniken in 2D-Grafiksystemen". Seminararbeit, FH Aachen, Campus Jülich (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/Seminararbeit_FlorianRhiem.pdf>`__)

* Heimbach, I. (2011), "Entwicklung eines logischen GKS Gerätetreibers für die wxWidgets-Klassenbibliothek". Seminararbeit, FH Aachen, Campus Jülich (`PDF <http://iffwww.iff.kfa-juelich.de/pub/doc/Seminararbeit_IngoHeimbach.pdf>`__)

